"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = ROOT_DB_HANDLER;
const serverless_mysql_1 = __importDefault(require("serverless-mysql"));
/**
 * # Root DB handler
 */
function ROOT_DB_HANDLER(...args) {
    const CONNECTION = (0, serverless_mysql_1.default)({
        config: {
            host: process.env.DSQL_DB_HOST,
            user: process.env.DSQL_DB_USERNAME,
            password: process.env.DSQL_DB_PASSWORD,
            database: process.env.DSQL_DB_NAME,
            port: process.env.DSQL_DB_PORT
                ? Number(process.env.DSQL_DB_PORT)
                : undefined,
            charset: "utf8mb4",
        },
    });
    try {
        return new Promise((resolve, reject) => {
            CONNECTION.query(...args)
                .then((results) => {
                CONNECTION.end();
                resolve(JSON.parse(JSON.stringify(results)));
            })
                .catch((err) => {
                CONNECTION.end();
                resolve({
                    error: err.message,
                    sql: err.sql,
                });
            });
        });
    }
    catch (error) {
        return {
            success: false,
            error: error.message,
        };
    }
    finally {
        CONNECTION === null || CONNECTION === void 0 ? void 0 : CONNECTION.end();
    }
}
